import { useState, useEffect } from 'react';
import { getSignedUrl } from '@/lib/actions';
import type { Profile } from '@/utils/supabase';
import { toast } from 'sonner';

export const useAvatar = (profile?: Profile) => {
  const [avatarUrl, setAvatarUrl] = useState<string | undefined>(undefined);
  const [isLoading, setIsLoading] = useState(false);

  useEffect(() => {
    const getAvatarUrl = async () => {
      if (profile?.avatar_url) {
        try {
          setIsLoading(true);
          const response = await getSignedUrl({
            bucket: 'avatars',
            url: profile.avatar_url,
            transform: {
              quality: 20,
            }
          });
          
          if (response.success) {
            setAvatarUrl(response.data);
          }
        } catch (error) {
          console.error('Error getting signed URL:', error);
        } finally {
          setIsLoading(false);
        }
      } else {
        setAvatarUrl(undefined);
      }
    };
    
    getAvatarUrl().catch((error) => {
      toast.error(error instanceof Error ? error.message : 'Failed to get signed avatar url.');
    });

  }, [profile]);

  return {
    avatarUrl,
    isLoading,
  };
}
